powered by
Downloads CVAP, block data, and block group data all together. Calls cvap_distribute within.
cvap_distribute
cvap_distribute_censable( state, year = 2023, clean = TRUE, wts = "pop", include_implied = TRUE )
cvap tibble estimated at the block level
character. The state to get data for or nation for the nation file.
numeric. Year for the data in 2009 to 2023.
Should variable names be standardized? Default is TRUE.
'pop' (default) or 'vap' for the group to distribute by.
logical if a column for the implied total (impl_cvap) should be included. Default is TRUE
impl_cvap
TRUE
if (FALSE) { # Requires API set up with tidycensus or censable cvap_distribute_censable('DE', 2019) }
Run the code above in your browser using DataLab